==> 3.5.12-core.tar: kdewebdev/quanta/dialogs/tagdialogs/tagquicklistdlg.h <==
/***************************************************************************
                          tagquicklistdlg.h  -  description
                             -------------------
    begin                : Sun Nov 28 1999
    copyright            : (C) 1999 by Yacovlev Alexander & Dmitry Poplavsky
    email                : pdima@mail.univ.kiev.ua
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TAGQUICKLISTDLG_H
#define TAGQUICKLISTDLG_H

#include <tqwidget.h>

#include <tqdialog.h>
class TQLabel;
class TQSpinBox;
class TQPushButton;
class TQRadioButton;
class TQButtonGroup;

/**
  *@author Dmitry Poplavsky & Yacovlev Alexander
  */

class TagQuickListDlg : public TQDialog  {
   Q_OBJECT
public:
  TagQuickListDlg(TQWidget *parent=0, const char *name=0);
  ~TagQuickListDlg();

public:
  void initDialog();
  TQLabel *QLabel_1;
  TQSpinBox *spinBoxRows;
  TQPushButton *buttonOk;
  TQLabel *QLabel_2;
  TQRadioButton *radioOrdered;
  TQRadioButton *radioUnordered;
  TQPushButton *buttonCancel;
  TQButtonGroup *groupBox;

private:
};

#endif

==> 3.5.13-core.tar: kdewebdev/quanta/dialogs/tagdialogs/tagquicklistdlg.h <==
/***************************************************************************
                          tagquicklistdlg.h  -  description
                             -------------------
    begin                : Sun Nov 28 1999
    copyright            : (C) 1999 by Yacovlev Alexander & Dmitry Poplavsky
    email                : pdima@mail.univ.kiev.ua
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TAGTQUICKLISTDLG_H
#define TAGTQUICKLISTDLG_H

#include <tqwidget.h>

#include <tqdialog.h>
class TQLabel;
class TQSpinBox;
class TQPushButton;
class TQRadioButton;
class TQButtonGroup;

/**
  *@author Dmitry Poplavsky & Yacovlev Alexander
  */

class TagQuickListDlg : public TQDialog  {
   Q_OBJECT
  TQ_OBJECT
public:
  TagQuickListDlg(TQWidget *parent=0, const char *name=0);
  ~TagQuickListDlg();

public:
  void initDialog();
  TQLabel *TQLabel_1;
  TQSpinBox *spinBoxRows;
  TQPushButton *buttonOk;
  TQLabel *TQLabel_2;
  TQRadioButton *radioOrdered;
  TQRadioButton *radioUnordered;
  TQPushButton *buttonCancel;
  TQButtonGroup *groupBox;

private:
};

#endif
